==> qtjambi-sensors-5.15.14-sources.jar: io/qt/sensors/QTapFilter.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Convenience wrapper around QSensorFilter</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qtapfilter.html">QTapFilter</a></p>
 */
public interface QTapFilter extends QtObjectInterface, io.qt.sensors.QSensorFilter
{
    /**
     * <p>Implementor class for interface {@link io.qt.sensors.QTapFilter}</p>
     */
    public static abstract class Impl extends QtObject
        implements io.qt.sensors.QTapFilter,
                io.qt.sensors.QSensorFilter
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @QtPropertyMember(enabled=false)
        private Object __rcSensor = null;
        
        @NativeAccess
        private static final class ConcreteWrapper extends QTapFilter.Impl {
            
            @NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @QtUninvokable
            public boolean filter(io.qt.sensors.@Nullable QTapReading reading){
                return filter_native_QTapReading_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reading));
            }
            private native static boolean filter_native_QTapReading_ptr(long __this__nativeId, long reading);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QTapFilter instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qsensorfilter.html#filter">QSensorFilter::filter(QSensorReading*)</a></p>
         */
        @Deprecated
        @QtUninvokable
        public final boolean filter(io.qt.sensors.@Nullable QSensorReading reading) throws QNoImplementationException {
            return filter_native_QSensorReading_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reading));
        }
        
        @Deprecated
        private static boolean filter_native_QSensorReading_ptr(long __this__nativeId, long reading) throws QNoImplementationException {
            throw new QNoImplementationException();
        }
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qtapfilter.html#filter">QTapFilter::filter(QTapReading*)</a></p>
         */
        @QtUninvokable
        public abstract boolean filter(io.qt.sensors.@Nullable QTapReading reading);
        
        private native static boolean filter_native_QTapReading_ptr(long __this__nativeId, long reading);
        
        @QtUninvokable
        protected void setSensor(io.qt.sensors.@Nullable QSensor sensor){
            setSensor_native_QSensor_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(sensor));
            __rcSensor = sensor;
        }
        
        private native static void setSensor_native_QSensor_ptr(long __this__nativeId, long sensor);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qtapfilter.html#filter">QTapFilter::filter(QTapReading*)</a></p>
     */
    @QtUninvokable
    public boolean filter(io.qt.sensors.@Nullable QTapReading reading);
    
}

==> qtjambi-sensors-6.2.1-sources.jar: io/qt/sensors/QTapFilter.java <==
package io.qt.sensors;


/**
 * <p>Java wrapper for Qt class QTapFilter</p>
 */
public interface QTapFilter extends io.qt.QtObjectInterface, io.qt.sensors.QSensorFilter
{
    /**
     * <p>Implementor class for interface {@link io.qt.sensors.QTapFilter}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.sensors.QTapFilter,
                io.qt.sensors.QSensorFilter
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.QtPropertyMember(enabled=false)
        private Object __rcSensor = null;
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QTapFilter.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public boolean filter(io.qt.sensors.QTapReading reading){
                return filter_native_QTapReading_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reading));
            }
            private native static boolean filter_native_QTapReading_ptr(long __this__nativeId, long reading);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QTapFilter instance);
        
        @Deprecated
        @io.qt.QtUninvokable
        public final boolean filter(io.qt.sensors.QSensorReading reading) throws io.qt.QNoImplementationException {
            return filter_native_QSensorReading_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reading));
        }
        
        @Deprecated
        private static boolean filter_native_QSensorReading_ptr(long __this__nativeId, long reading) throws io.qt.QNoImplementationException {
            throw new io.qt.QNoImplementationException();
        }
        @io.qt.QtUninvokable
        public abstract boolean filter(io.qt.sensors.QTapReading reading);
        
        private native static boolean filter_native_QTapReading_ptr(long __this__nativeId, long reading);
        
        @io.qt.QtUninvokable
        protected void setSensor(io.qt.sensors.QSensor sensor){
            setSensor_native_QSensor_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(sensor));
            __rcSensor = sensor;
        }
        
        private native static void setSensor_native_QSensor_ptr(long __this__nativeId, long sensor);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    @io.qt.QtUninvokable
    public boolean filter(io.qt.sensors.QTapReading reading);
    
}
